@@ -4,6 +4,8 @@
 
 # flake8: noqa
 
+from .. import __version__
+
 from .basecommand import BaseCommand
 
 from .apicommand import ApiCommand
@@ -14,3 +16,4 @@ from .testcommand import TestCommand
 from .closecommand import CloseCommand
 from .opencommand import OpenCommand
 from .configcommand import ConfigCommand
+from .mtacommand import MTACommand
